==> luckperms-api-4.1-sources.jar: me/lucko/luckperms/api/event/source/Source.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api.event.source;

import me.lucko.luckperms.api.Entity;

import javax.annotation.Nonnull;

/**
 * Represents the source of an event.
 *
 * <p>Could also be described as the "thing" that caused an event to occur.</p>
 *
 * @since 4.1
 */
public interface Source {

    /**
     * Gets the source type
     *
     * @return the type
     */
    @Nonnull
    Type getType();

    /**
     * Represents a type of source
     */
    enum Type {

        /**
         * Represents an {@link Entity} source
         *
         * @see EntitySource
         */
        ENTITY,

        /**
         * Represents an unknown source
         */
        UNKNOWN
    }

}

==> luckperms-api-4.3-sources.jar: me/lucko/luckperms/api/event/source/Source.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api.event.source;

import me.lucko.luckperms.api.Entity;

import org.checkerframework.checker.nullness.qual.NonNull;

/**
 * Represents the source of an event.
 *
 * <p>Could also be described as the "thing" that caused an event to occur.</p>
 *
 * @since 4.1
 */
public interface Source {

    /**
     * Gets the source type
     *
     * @return the type
     */
    @NonNull Type getType();

    /**
     * Represents a type of source
     */
    enum Type {

        /**
         * Represents an {@link Entity} source
         *
         * @see EntitySource
         */
        ENTITY,

        /**
         * Represents an unknown source
         */
        UNKNOWN
    }

}
